pilas.actores.piedra

Package pilas :: Package actores :: Module piedra |
[hide private]
[frames] | no frames]

# Source Code for Module pilas.actores.piedra

     1  # -*- encoding: utf-8 -*-
     2  # Pilas engine - A video game framework.
     3  #
     4  # Copyright 2010 - Hugo Ruscitti
     5  # License: LGPLv3 (see http://www.gnu.org/licenses/lgpl.html)
     6  #
     7  # Website - http://www.pilas-engine.com.ar
     8
     9  from pilas.actores import Actor
    10  import pilas
    11
    12 -class Piedra(Actor):
    13      """Representa una piedra que podría ser usada como meteoríto."""
    14
    15 -    def __init__(self, x=0, y=0, tamano="grande", dx=0, dy=0):
    16          """Genera el actor.
    17
    18          :param x: Posición horizontal del actor.
    19          :param y: Posición vertical del actor.
    20          :param tamano: Tamaño que tendrá la piedra, puerde ser "grande", "media" o  "chica"
    21          :param dx: Velocidad horizontal del movimiento.
    22          :param dy: Velocidad vertical del movimiento.
    23          """
    24
    25          imagen = pilas.imagenes.cargar('piedra_' + tamano + '.png')
    26          Actor.__init__(self, imagen)
    27          self.rotacion = 0
    28          self.x = x
    29          self.y = y
    30          self.dx = dx
    31          self.dy = dy
    32
    33          radios = {
    34                  'grande': 25,
    35                  'media': 20,
    36                  'chica': 10,
    37                  }
    38
    39          self.radio_de_colision = radios[tamano]
    40          self.aprender(pilas.habilidades.SeMantieneEnPantalla)
    41
    42 -    def actualizar(self):
    43          "Realiza una actualización de la posición."
    44          self.rotacion += 1
    45          self.x += self.dx
    46          self.y += self.dy
    47